@@ -57,6 +57,7 @@ class Consul(object):
             host='127.0.0.1',
             port=8500,
             token=None,
+            scheme='http',
             consistency='default'):
         """
         *token* is an optional `ACL token`_. If supplied it will be used by
@@ -72,8 +73,9 @@ class Consul(object):
 
         # TODO: Event, Status
 
-        self.http = self.connect(host, port)
+        self.http = self.connect(host, port, scheme)
         self.token = token
+        self.scheme = scheme
         assert consistency in ('default', 'consistent', 'stale')
         self.consistency = consistency
 
@@ -123,6 +125,10 @@ class Consul(object):
                     "Value": "bar",
                     "Session": "adf4238a-882b-9ddc-4a9d-5b6758e4159e"
                 }
+
+            Note, if the requested key does not exists *(index, None)* is
+            returned. It's then possible to long poll on the index for when the
+            key is created.
             """
             assert not key.startswith('/')
             params = {}
@@ -245,8 +251,7 @@ class Consul(object):
         takes on the burden of registering with the Catalog and performing
         anti-entropy to recover from outages.
         """
-        # TODO: checks, members, join, force-leave
-        # TODO: Check. register, deregister, pass (move), warn, fail
+        # TODO: join, force-leave
         def __init__(self, agent):
             self.agent = agent
             self.service = Consul.Agent.Service(agent)
@@ -287,15 +292,24 @@ class Consul(object):
             return self.agent.http.get(
                 lambda x: json.loads(x.body), '/v1/agent/checks')
 
-        def members(self):
+        def members(self, wan=False):
             """
             Returns all the members that this agent currently sees. This may
             vary by agent, use the nodes api of Catalog to retrieve a cluster
-            wide consistent view of members
+            wide consistent view of members.
+
+            For agents running in server mode, setting *wan* to *True* returns
+            the list of WAN members instead of the LAN members which is
+            default.
             """
-            # TODO: add wan flag
+            params = {}
+            if wan:
+                params['wan'] = 1
+
             return self.agent.http.get(
-                lambda x: json.loads(x.body), '/v1/agent/members')
+                lambda x: json.loads(x.body),
+                '/v1/agent/members',
+                params=params)
 
         class Service(object):
             def __init__(self, agent):
